@@ -34,6 +34,10 @@
 #include "oxygensliderdemowidget.h"
 #include "oxygentabdemowidget.h"
 #include "config-liboxygen.h"
+#ifdef HAVE_SCHEME_CHOOSER
+#include "oxygenschemechooser.h"
+#include "oxygenstylechooser.h"
+#endif
 
 #include <QTextStream>
 #include <QShortcut>
@@ -78,6 +82,17 @@ namespace Oxygen
         connect( _rightToLeftCheckBox, SIGNAL(toggled(bool)), SLOT(toggleRightToLeft(bool)) );
         buttonBox->addButton( _rightToLeftCheckBox, QDialogButtonBox::ResetRole );
 
+#ifdef HAVE_SCHEME_CHOOSER
+        WidgetStyleChooser *styleChooser = new WidgetStyleChooser(this);
+        styleChooser->setFlat( true );
+        styleChooser->createStyleSelectionMenu( i18n( "Style" ) );
+        buttonBox->addButton( styleChooser, QDialogButtonBox::ResetRole );
+
+        ColorSchemeChooser *colChooser = new ColorSchemeChooser( this );
+        colChooser->setFlat( true );
+        buttonBox->addButton( colChooser, QDialogButtonBox::ResetRole );
+#endif
+
         // connections
         connect( pageWidget, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), SLOT(updateWindowTitle(KPageWidgetItem*)) );
         connect( pageWidget, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), SLOT(updateEnableState(KPageWidgetItem*)) );
